## v0.1.2 (2024-08-15)

### Fix

- **scope**: remove trailing whitespace in body ([e7383d9](https://github.com/kmnhan/cz-changeup/commit/e7383d924051cc4b0eb0f4d7a61da32941d200d9))

## 0.1.1 (2024-08-15)

### Fix

- change config ([3c6c7b9](https://github.com/kmnhan/cz-changeup/commit/3c6c7b9fa18c59cc813a0438a08ef9e6445b8f3f))

  Project configuration has been modified to include the link to the commit in the changelog. Also added all settings provided by this plugin to `pyproject.toml` for demonstration.
  
  This is the footer content added to demonstrate how the changelog is rendered.

### Refactor

- add license file ([518c296](https://github.com/kmnhan/cz-changeup/commit/518c29667f5b28440b447724b93b59a0976c1905))

## 0.1.0 (2024-08-15)

### Feat

- initial release
